@@ -86,6 +86,8 @@ class ProjectTest(unittest.TestCase):
         os.chdir(test_bin)
         try:
             os.mkdir(os.path.join(test_bin, 'bin'))
+            os.mkdir(os.path.join(test_bin, 'Scripts'))
+                
             f = open(os.path.join(test_bin, 'bin', 'python'), 'w')
             f.write('#')
             f.close()
@@ -97,6 +99,13 @@ class ProjectTest(unittest.TestCase):
             f.close()
             python = _python()    
             self.assertEquals(python, 'bin/python2.4')
+            os.remove(python)
+            f = open(os.path.join(test_bin, 'Scripts', 'python'), 'w')
+            f.write('#')
+            f.close()
+            python = _python()    
+            self.assertEquals(python, 'Scripts/python')
+
         finally:
             shutil.rmtree(test_bin)
 
